@@ -4,11 +4,37 @@ use 5.006001;
 use strict;
 use warnings;
 
-our $VERSION = '0.016';
+our $VERSION = '0.017';
 
 require XSLoader;
 XSLoader::load('Conf::Libconfig', $VERSION);
 
+sub add {
+   my ($self, $path, $key, $item) = @_;
+   return unless defined $item;
+   my $ref = ref $item;
+   my $subpath = join '.', grep { $_ ne '' } $path, $key;
+   if (!$ref) {
+      $self->add_scalar($path, $key, $item);
+   }
+   elsif ($ref eq 'ARRAY') {
+      $self->add_list($path, $key, []);
+      for my $ii (0 .. $#{$item}) {
+         $self->add($subpath, "[$ii]", $item->[$ii]);
+      }
+   }
+   elsif ($ref eq 'HASH') {
+      $self->add_hash($path, $key, {});
+      for my $subkey (keys %$item) {
+         $self->add($subpath, $subkey, $item->{$subkey});
+      }
+   }
+   else {
+      return;
+   }
+   return 1;
+}
+
 1;
 __END__
 
@@ -44,19 +70,19 @@ None by default.
 
 =head2 $self->new()
 
-Construct.
+construct.
 
 =head2 $self->delete()
 
-Destructor.
+destruct.
 
 =head2 $self->DESTROY()
 
-Destructor, and auto release memory.
+destruct and auto release memory.
 
 =head2 $self->read_file ($file)
 
-Read config file.
+read config file.
 
 =head2 $self->write($buffer)
 
@@ -68,7 +94,7 @@ write to a file.
 
 =head2 $self->lookup_value ($path)
 
-Automatically check and get value from config file, suggest use it.
+automatically check and get value from config file, suggest use it.
 
 =head2 $self->setting_lookup ($path)
 
@@ -82,6 +108,10 @@ return array list from path.
 
 return hash reference from path.
 
+=head2 $self->add($path, $key, $item)
+
+add a struct data for $key.
+
 =head2 $self->add_scalar ($path, $key, $value)
 
 add a pair of key and value node to handle and return true if add successfully.
@@ -128,23 +158,23 @@ return value type of setting resource.
 
 =head2 $self->lookup_bool ($path)
 
-Only get value type of bool from config file, please use lookup_value replace it.
+only get value type of bool from config file, please use lookup_value replace it.
 
 =head2 $self->lookup_int ($path)
 
-Only get value type of long int from config file, please use lookup_value replace it.
+only get value type of long int from config file, please use lookup_value replace it.
 
 =head2 $self->lookup_int64 ($path)
 
-Only get value type of long long int from config file, please use lookup_value replace it.
+only get value type of long long int from config file, please use lookup_value replace it.
 
 =head2 $self->lookup_float ($path)
 
-Only get value type of float from config file, please use lookup_value replace it.
+only get value type of float from config file, please use lookup_value replace it.
 
 =head2 $self->lookup_string ($path)
 
-Only get value type of string from config file, please use lookup_value replace it.
+only get value type of string from config file, please use lookup_value replace it.
 
 =head1 PREREQUISITES
 
